#
# spec file for package python-nbsphinx
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-nbsphinx
Version:        0.9.3
Release:        1.1
Summary:        Jupyter Notebook Tools for Sphinx
License:        MIT
URL:            https://github.com/spatialaudio/nbsphinx/
Source:         https://files.pythonhosted.org/packages/source/n/nbsphinx/nbsphinx-%{version}.tar.gz
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module Sphinx >= 1.8}
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module nbconvert}
BuildRequires:  %{python_module nbformat}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module traitlets >= 5}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-Sphinx >= 1.8
Requires:       python-docutils
Requires:       python-nbconvert
Requires:       python-nbformat
Requires:       python-traitlets >= 5
Recommends:     mathjax
Recommends:     pandoc
Provides:       python-jupyter_nbsphinx = %{version}
Obsoletes:      python-jupyter_nbsphinx < %{version}
BuildArch:      noarch
%if "%{python_flavor}" == "python3" || "%{?python_provides}"  == "python3"
Provides:       jupyter-nbsphinx = %{version}
%endif
%python_subpackages

%description
The nbsphinx package is a Sphinx extension that provides a source
parser for *.ipynb files. Custom Sphinx directives are used to show
Jupyter Notebook code cells (and of course their results) in both HTML
and LaTeX output. Un-evaluated notebooks – i.e. notebooks without
stored output cells – will be automatically executed during the Sphinx
build process.

%prep
%setup -q -n nbsphinx-%{version}

%build
%pyproject_wheel

%install
%pyproject_install

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%{python_expand # no other unit tests provided
# import the module.
export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -c 'import nbsphinx'
# We cannot test it on our own doc/ because we lack the right Sphinx packages
#$python -m sphinx doc/ _build/ -Dsuppress_warnings=git.too_shallow -b html
}

%files %{python_files}
%doc NEWS.rst README.rst
%license LICENSE
%{python_sitelib}/nbsphinx
%{python_sitelib}/nbsphinx-%{version}.dist-info

%changelog
* Sun Aug 27 2023 Arun Persaud <arun@gmx.de>
- update to version 0.9.3:
  * Fix gallery regression in Sphinx 7.2
* Fri Jun  2 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.9.2
  * Improve support for sphinx_immaterial theme
  * Improve support for links starting with #
  * Add support for in-text citations
  * LaTeX: Add support for admonition titles
* Sun Mar 19 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.9.1
  * pandoc: disable "smart" option only for version 2.0+
- Version 0.9.0
  * Split nbsphinx.py (a Python module) into:
  - nbsphinx/__init__.py (a Python package)
  - A standalone CSS file nbsphinx-code-cells.css_t
  - LaTeX style file nbsphinx.sty
  * Add custom HTML/CSS for thumbnail galleries
  - Separate CSS file nbsphinx-gallery.css
  - The CSS from Sphinx Gallery ('sphinx_gallery.load_style')
    cannot be used anymore
  * Use the last image in a notebook as the default thumbnail
* Sun Jan 22 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.8.12
  * Implement "link" galleries (without nested sub-documents)
* Sun Jan  8 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.8.11
  * LaTeX: apply code cell border style to all code blocks
- Release 0.8.10
  * Fix handling of source_suffix
  * A few LaTeX fixes
* Fri Jun 17 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to Version 0.8.9
  * CSS: support tables in widgets
  * Avoid empty "raw" directive
* Sun Feb 27 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 0.8.8:
  * Support for the sphinx_codeautolink extension
  * Basic support for the text builder
- changes from version 0.8.7:
  * Fix assertion error in LaTeX build with Sphinx 4.1.0+
* Thu Jul  1 2021 Ben Greiner <code@bnavigator.de>
- Update to Version 0.8.6
  * Support for Jinja2 version 3
- Release 0.8.5
  * Freeze Jinja2 version to 2.11 (for now, until a bugfix is found)
  * Add ``theme_comparison.py`` tool for creating multiple versions
  (with different HTML themes) of the docs at once
- Release 0.8.4
  * Support for ``mathjax3_config`` (for Sphinx >= 4)
  * Force loading MathJax on HTML pages generated from notebooks
  (can be disabled with ``nbsphinx_assume_equations = False``)
- Release 0.8.3
  * Increase ``line_length_limit`` (for `docutils` 0.17+)
- Release 0.8.2
  * Add support for ``data-footcite`` HTML attribute
  * Disable automatic highlighting in notebooks,
  setting ``highlight_language`` is no longer needed
- Release 0.8.1
  * Minor fixes and documentation update
* Thu Dec 17 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 0.8
  * Don't overwrite Pygments background in notebook code
    cells. To get rid of those ugly greenish code blocks,
    remove pygments_style = 'sphinx' from your conf.py.
  * Switch documentation to insipid theme by default
  * Require Python 3.6+
- The only test upstream does is to import the module and run
  sphinx on their own docs. We can't do the latter because
  we don't have all the requirements
* Tue Dec 15 2020 Benjamin Greiner <code@bnavigator.de>
- Provide the old jupyter package name only for the primary
  Python3 interpreter -- gh#openSUSE/python-rpm-macros#66
* Wed Jul  1 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.7.1
  * Avoid links on scaled images
* Tue Jun  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.0:
  * Warnings can be suppressed with suppress_warnings.
  * CSS: prompts protrude into left margin if nbsphinx_prompt_width is
  too small
  * <img> tags are handled in Markdown cells
* Sat May  2 2020 Arun Persaud <arun@gmx.de>
- update to version 0.6.1:
  * .ipynb_checkpoints is automatically added to exclude_patterns
- changes from version 0.6.0:
  * Thumbnail galleries (inspired by
    https://sphinx-gallery.github.io/)
  * nbsphinx-toctree as cell tag
  * Keyword arguments in nbsphinx_custom_formats
  * Python 2 support has been dropped
* Mon Feb 10 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.5.1
  * This will be the last release supporting Python 2.x!
  * Support for https://github.com/choldgraf/sphinx-copybutton
  * Executed notebooks are now saved in the HTML output directory
* Wed Jan 15 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.5.0
  * Automatic support for Jupyter widgets,
    customizable with nbsphinx_widgets_path\
    (and nbsphinx_widgets_options)
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- Latest release drops python2 support.
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.4.3
  * Add option nbsphinx_requirejs_path (and nbsphinx_requirejs_options)
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.4.2
  * Re-establish Python 2 compatibility (but the clock is ticking ...)
- Rename to to match python package naming guidelines.
- Split jupyter components into own subpackage.
* Mon Feb 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop dependency on deprecated python-py package as it is not
  stated anywhere in the upstream sources
* Mon Jan  7 2019 Todd R <toddrme2178@gmail.com>
- This is python3-only.
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to Version 0.4.1
  * Fix issue #266
- Update to Version 0.4.0
  * Support for "data-cite" HTML tags in Markdown cells
  * Add option ``nbsphinx_custom_formats``
  * LaTeX macros ``\nbsphinxstartnotebook`` and ``\nbsphinxstopnotebook``
  * Support for cell attachments
  * Add options ``nbsphinx_input_prompt`` and ``nbsphinx_output_prompt``
  * Re-design LaTeX output of code cells, fix image sizes
* Fri Sep 28 2018 Todd R <toddrme2178@gmail.com>
- Update to 0.3.5
  * Disable nbconvert version 5.4 to avoid jupyter/nbconvert#878
* Fri Sep  7 2018 toddrme2178@gmail.com
- Update to 0.3.4
  * Fix issue #196 and other minor changes
* Sat Apr 28 2018 toddrme2178@gmail.com
- Update to version 0.3.3
  * Locally linked files are only copied for Jupyter notebooks
    (and not anymore for other Sphinx source files)
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 0.3.2
  * Links to local files are rewritten for all Sphinx source files (not only
    Jupyter notebooks)
* Thu Jan 18 2018 toddrme2178@gmail.com
- Update to version 0.3.1
  * Enable notebook translations (NB: The use of reST strings is temporary!)
- Update to version 0.3.0
  * Add options ``nbsphinx_prolog`` and ``nbsphinx_epilog``
  * Links from ``*.rst`` files to notebooks have to start with a slash
* Sun Dec  3 2017 arun@gmx.de
- update to version 0.2.18:
  * Fix issue #148
* Tue Nov 14 2017 arun@gmx.de
- update to version 0.2.17:
  * Fix issue #146
- changes from version 0.2.16:
  * Fix issue #142
- changes from version 0.2.15 :
  * Links to subsections are now possible in all source files
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 0.2.14
  * Add option ``nbsphinx_kernel_name``
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Initial version.
